@@ -36,9 +36,7 @@
 #define OBS(i, name, desc) { name, #name, desc }
 #endif
 
-/* *INDENT-OFF* */
-static struct
-{
+static struct {
   int rc;
   const char *name;
   const char *description;
@@ -198,10 +196,11 @@ static struct
        N_("GSSAPI error testing for OID in OID set.")),
   ERR (GSASL_GSSAPI_RELEASE_OID_SET_ERROR,
        N_("GSSAPI error releasing OID set.")),
-  ERR (GSASL_NO_CB_TLS_UNIQUE,
-       N_("Authentication failed because a tls-unique CB was not provided."))
+  ERR (GSASL_NO_SAML20_IDP_IDENTIFIER,
+       N_("Callback failed to provide SAML20 user identifier.")),
+  ERR (GSASL_NO_SAML20_REDIRECT_URL,
+       N_("Callback failed to provide SAML20 redirect URL.")),
 };
-/* *INDENT-ON* */
 
 /**
  * gsasl_strerror:
