@@ -1,5 +1,5 @@
 /* property.c --- Callback property handling.
- * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -100,6 +100,18 @@ map (Gsasl_session * sctx, Gsasl_property prop)
       p = &sctx->scram_salted_password;
       break;
 
+    case GSASL_SAML20_IDP_IDENTIFIER:
+      p = &sctx->saml20_idp_identifier;
+      break;
+
+    case GSASL_SAML20_REDIRECT_URL:
+      p = &sctx->saml20_redirect_url;
+      break;
+
+      /* If you add anything here, remember to change change
+	 gsasl_finish() in xfinish.c and Gsasl_session in
+	 internal.h.  */
+
     default:
       break;
     }
